package com.coldlightalchemist.interactivitystatesharingexample;

import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.widget.Button;
import android.widget.EditText;

import androidx.activity.EdgeToEdge;
import androidx.activity.OnBackPressedCallback;
import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;

import java.util.Objects;

public class FirstActivity extends AppCompatActivity {

    private EditText enterStringField;

    private Button moveToSecondActivity;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_first);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        Context context = getApplicationContext();
        InterActivityState state = (InterActivityState) Objects.requireNonNull(getIntent().getExtras()).get(Constants.kInterActivityStateKey);

        this.getOnBackPressedDispatcher().addCallback(new OnBackPressedCallback(true) {
            @Override
            public void handleOnBackPressed() {
                AlertDialog.Builder alertBuilder = new AlertDialog.Builder(context);
                DialogInterface.OnClickListener listener = (d, w) -> {
                    switch(w) {
                        case DialogInterface.BUTTON_POSITIVE:
                            finish();
                            break;
                        case DialogInterface.BUTTON_NEGATIVE:
                            break;
                    }
                };

                alertBuilder.setMessage("Are you sure you want to back out, the data you've entered so far will be lost!")
                        .setPositiveButton("Yes", listener)
                        .setNegativeButton("No", listener)
                        .show();
            }
        });

        enterStringField = (EditText) findViewById(R.id.enterStringField);
        enterStringField.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                assert state != null;
                state.setFirstActivityString(s.toString());
            }
        });

        moveToSecondActivity = (Button) findViewById(R.id.moveToSecondActivity);
        moveToSecondActivity.setOnClickListener((v) -> {
            Intent secondActivityIntent = new Intent(v.getContext(), SecondActivity.class);
            secondActivityIntent.putExtra(Constants.kInterActivityStateKey, state);
            startActivity(secondActivityIntent);
        });

    }
}