package com.coldlightalchemist.interactivitystatesharingexample;

import static android.view.View.INVISIBLE;
import static android.view.View.VISIBLE;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.activity.OnBackPressedCallback;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import org.w3c.dom.Text;

import java.io.File;
import java.io.IOException;
import java.nio.file.Paths;
import java.util.List;
import java.util.Map;

public class MainActivity extends AppCompatActivity {
    private InterActivityState interActivityState;

    private Button startDataEntry;

    private TextView nothingInFile;

    private RecyclerView dataInFile;

    private File dataFile;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_main);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        dataFile = new File(getFilesDir(), Constants.kFileName);

        startDataEntry = (Button) findViewById(R.id.startDataEntry);
        startDataEntry.setOnClickListener((v) -> {
            interActivityState = new InterActivityState(dataFile);
            Intent firstActivityIntent = new Intent(v.getContext(), FirstActivity.class);
            firstActivityIntent.putExtra(Constants.kInterActivityStateKey, interActivityState);
            startActivity(firstActivityIntent);
        });

        nothingInFile = (TextView) findViewById(R.id.nothingInFile);

        dataInFile = (RecyclerView) findViewById(R.id.dataInFile);
        dataInFile.setLayoutManager(new LinearLayoutManager(this));

        try {
            List<Map<String, String>> currentFileData = Utilities.readFormattedCSV(dataFile);

            if (currentFileData == null || currentFileData.isEmpty()) {
                nothingInFile.setVisibility(VISIBLE);
                dataInFile.setVisibility(INVISIBLE);
            } else {
                nothingInFile.setVisibility(INVISIBLE);
                dataInFile.setVisibility(VISIBLE);

                Log.d("RECYCLER DATA", "Recycler Data Size: " + currentFileData.size());

                StoredDataRecyclerViewAdapter adapter = new StoredDataRecyclerViewAdapter(currentFileData);
                dataInFile.setAdapter(adapter);
            }
        } catch (IOException e) {
            nothingInFile.setVisibility(VISIBLE);
            dataInFile.setVisibility(INVISIBLE);
            Log.d("FILE READ", "Failed to read the data file for some reason", e);
        }

    }
}