package com.coldlightalchemist.interactivitystatesharingexample;

import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.Log;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;

import java.io.IOException;
import java.util.Objects;

public class SecondActivity extends AppCompatActivity {
    private EditText editNumber;

    private Button increaseNumber;
    private Button saveToFile;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_second);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        InterActivityState state = (InterActivityState) Objects.requireNonNull(getIntent().getExtras()).get(Constants.kInterActivityStateKey);

        editNumber = (EditText) findViewById(R.id.editNumber);
        editNumber.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                assert state != null;
                state.setSecondActivityInt(Integer.parseInt(s.toString()));
            }
        });

        increaseNumber = (Button) findViewById(R.id.increaseNumber);
        increaseNumber.setOnClickListener((v) -> {
            int newNumber = Integer.parseInt(editNumber.getText().toString()) + 1;
            editNumber.getText().replace(0, editNumber.getText().length(), Integer.toString(newNumber));
        });

        saveToFile = (Button) findViewById(R.id.saveToFile);
        saveToFile.setOnClickListener((v) -> {
            try {
                assert state != null;
                state.writeToFile();

                Toast.makeText(v.getContext(), "File Saved", Toast.LENGTH_LONG).show();
                Intent intent = new Intent(v.getContext(), MainActivity.class);
                intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
                startActivity(intent);
                finish();
            } catch (IOException e) {
                Toast.makeText(v.getContext(), "Something went wrong saving to file", Toast.LENGTH_LONG).show();
                Log.d("FILE SAVE", "Something went wrong saving to file", e);
            }
        });
    }
}